dojo.provide("com.ibm.pb.decorations.LayoutResizers");

dojo.require("com.ibm.pb.screen.position");
dojo.require("com.ibm.pb.layout.LayoutParser");

dojo.declare("com.ibm.pb.decorations.LayoutResizers", com.ibm.pb.logging.Loggable, {
	components: {},
	runtimeModel: null,
	layoutParser: com.ibm.pb.layout.LayoutParser,
	
	constructor: function(){
		var mname = "constructor", lgr = this.LOGGER;
		lgr.entering(mname, arguments);

		// get the runtime skin model
		this.runtimeModel = com.ibm.mashups.enabler.runtime.skin.Factory.getRuntimeSkinModel();
		
		lgr.exiting(mname);
	},
	processContainer: function(id, node){
		var mname = "processContainer", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		
		if(this.components[id]){
			this.destroy(id);
		}
		
		// Search for containers to right of container
		var containers = this.layoutParser.findContainers(this.layoutParser.getRootNode());
		var nodes = com.ibm.pb.screen.position.findByDirection(node, containers, "right", true);
		
		lgr.trace(mname, "Found containers %o to the right of %o", nodes, node);
		
		// if nodes were found to the right of the container, create resizer widget
		if(nodes.length > 0){
			var leftNodeId = this.layoutParser.extractID(node);
			var rightNodeId = this.layoutParser.extractID(nodes[0]);
			
			//following line is used to avoid adding container resizer to hidden area in IE6
			if(dojo.isIE == 6 && leftNodeId == rightNodeId) return;
			
			var root = this.layoutParser.getRootNode();
			if(root) {
				// if root was found, calculate height of layout to apply to resizer
				var height = root.offsetHeight;
				while(height <= 0){
					// height was not found, move up the tree to find a height
					height = root.parentNode.offsetHeight;
				}		
			}			
			
			//var leftNodeId = this.layoutParser.extractID(node);
			//var rightNodeId = this.layoutParser.extractID(nodes[0]);
			
			var resizer = new com.ibm.pb.layout.resize.ContainerResizer({   
				height: height,
				leftNodeId: leftNodeId,
				rightNodeId: rightNodeId,
				runtimeNodes: {
					//#19024 lazy find the node until edit mode
					//left: this.runtimeModel.find(leftNodeId),
					//right: this.runtimeModel.find(rightNodeId)
					left: null,
					right: null
				}
			});
			if (!ibmCfg.themeConfig.isRTL) {
				dojo.place(resizer.domNode, node, "after");
			}else{
				dojo.place(resizer.domNode, node, "before");
			}
			
			this.components[id] = resizer;
		}		
	},
	destroy: function(id) {
		var mname = "destroy", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		
		var ret = false;
		if(id){
			if (this.components[id]) {
				this.components[id].destroy();
				delete this.components[id];
				ret = true;
			}
		}else{
			for(var id in this.components) {
				if(this.components[id]){
					this.components[id].destroy();
					delete this.components[id];
				}
			}
			ret = true;
		}
		this.inherited(arguments);
		return ret;
	}
});