dojo.provide("com.ibm.pb.screen.GridZone");

dojo.declare("com.ibm.pb.screen.GridZone",
	com.ibm.pb.screen.ZonedContainer,
	{
		// summary: A module that represents a zoned grid over a particular DOM node
		//		and provides an API for determining which zone in the grid a set of
		//		coordinates resides in.  The grid is regular, meaning that each zone
		//		in the grid has the same size, dimensions, and aspect ratio.
	
		constructor: function(node, params) {
			this.rezone(params);
		},
		getZone: function(coords) {
			var c = this._getCol(coords.x), r = this._getRow(coords.y);
			return this.getZoneNumber(r, c);
		},
		getZoneNumber: function(rowIdx, colIdx) {
			return this.cols * rowIdx + colIdx + 1;
		},
		_getIdx: function(c, abs, num) {
			var intv = abs / num;
			if(c < 0 || c >= abs) return -1;
			else return Math.ceil((c + 1) / intv);
		},
		_getRow: function(y) {
			return this._getIdx(y, dojo.style(this.node, "height"), this.rows);
		},
		_getCol: function(x) {
			return this._getIdx(x, dojo.style(this.node, "width"), this.cols);
		},
		rezone: function(params) {
			this.rows = params.rows;
			this.cols = params.cols;
		},
		_getZoneSpotDims: function(box, rowIdx, colIdx) {
			return {
				w: box.w / this.cols, 
				h: box.h / this.rows
			};
		},
		_createZoneSpot: function(box, rowIdx, colIdx) {
			var dims = this._getZoneSpotDims(box, rowIdx, colIdx);
			var zoneSpot = new com.ibm.pb.screen.ZoneSpot({
				style: {
					width: dims.w + "px",
					height: dims.h + "px",
					verticalAlign: "middle",
					textAlign: "center"
				},
				label: this.getZoneNumber(rowIdx, colIdx)
			});
			zoneSpot.startup();
			return zoneSpot.domNode;
		},
		fillZoneOverlayContents: function(node) {
			var box = dojo.contentBox(node);
			var zw = box.w / this.cols,
				zh = box.h / this.rows;
			var tbl = dojo.create("table", {
				cellspacing: 0, 
				cellpadding: 0,
				width: "100%",
				style: {
					borderCollapse: "collapsed",
					border: "none"
				}
			}, node);
			var tbody = dojo.create("tbody", null, tbl);
			for(var i = 0; i < this.rows; i++) {
				var tr = dojo.create("tr", null, tbody);
				for(var j = 0; j < this.cols; j++) {
					tr.appendChild(this._createZoneSpot(box, i, j));
				}
			}
		}
	}
);

dojo.declare("com.ibm.pb.screen.ZoneSpot",
	[dijit._Widget, dijit._Templated],
	{
		label: "",
		"class": "zone",
		
		templateString: 
			 "<td class='${class}' dojoAttachEvent='onmouseenter:onHover,onmouseleave:onUnhover'>"
			 	+"<span class='zoneLabel'>${label}</span>"
			+"</td>",
			
		onHover: function(evt) {
			dojo.addClass(this.domNode, "zoneOver");
		},
		onUnhover: function(evt) {
			dojo.removeClass(this.domNode, "zoneOver");
		}
	}
);
