/* Copyright IBM Corp. 2013  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.TreeModelController");

dojo.require("com.ibm.mashups.enabler.TreeModel");

/**
 * This modifiable interface provides a generic tree model acting as a base class
 * for all concrete tree models
 * @ibm-api
 * @ibm-module Base
 */
dojo.declare("com.ibm.mashups.enabler.TreeModelController", com.ibm.mashups.enabler.TreeModel, {
    /**
     * creates a new model object. The created node can be inserted
     * into the model using an appropriate <code>insert</code> method defined
     * on a subinterface of this interface. The node will not appear in the model
     * unless it is inserted.
     * @param {JSON} context array of predefined information
     * used for the creation of the node. May be <code>null</code>. Accepted
     * names are defined in the appropriate subinterfaces
     * @type Object
     * @return the created node
     */
    create: function(context){
    },
    
    /**
     * Confirms whether creating the node is possible.
     * @param {JSON} context array of predefined information
     * used for the creation of the node. May be <code>null</code>. Accepted
     * names are defined in the appropriate subinterfaces
     * @return {Boolean} true if the node can be created, otherwise false.
     */
    confirmCreate: function(context){
    },
    
    /**
     * Inserts a node into the tree model at the specified location;
     * the node must either be created with the create method of the
     * concrete tree model before, or must exist in the tree model;
     * in this case the existing node is moved to the specified location
     *
     * @param {Object} node         node to insert or move. Must not be
     *                              <code>null</code>.
     * @param {Object} parentNode   node object or node uri (without any
     *                              scope) of the parent node. The given
     *                              node is inserted/moved underneath the
     *                              parent node; must not be <code>null</code>.
     * @param {Object} nextNode     node object or node uri (without any
     *                              scope) of the successor node before
     *                              which the node is to be inserted;
     *                              if <code>null</code> is specified,
     *                              the node is appended at the end of
     *                              the existing nodes
     * @type void
     */
    insert: function(node, parentNode, nextNode){
    },
    
    /**
     * Confirms whether inserting the node is possible.
     * @param {Object} node         node to insert or move. Must not be
     *                              <code>null</code>.
     * @param {Object} parentNode   node object or node uri (without any
     *                              scope) of the parent node. The given
     *                              node is inserted/moved underneath the
     *                              parent node; must not be <code>null</code>.
     * @param {Object} nextNode     node object or node uri (without any
     *                              scope) of the successor node before
     *                              which the node is to be inserted;
     *                              if <code>null</code> is specified,
     *                              the node is appended at the end of
     *                              the existing nodes
     * @return {Boolean} true if the node can be inserted, otherwise false.
     */
    confirmInsert: function(node, parentNode, nextNode){
    },
    
    /**
     * Deletes a node from the model. All its children are deleted as well.
     *
     * @param {Object} node node object or node uri (without any scope)
     *                      to delete from the model. Must not be <code>null</code>.
     * @type void
     */
    remove: function(node){
    },
    
    /**
     * Confirms whether removing the node is possible.
     * @param{Object} node  node object or node uri (without any scope).
     *                      Must not be <code>null</code>
     * @return {Boolean} true if the node can be removed, otherwise false.
     */
    confirmRemove: function(node){
    }
});
